import  { useState } from 'react'
import { useFormik, Form, FormikProvider } from 'formik'; // import { useNavigate } from 'react-router-dom';
import { Stack, TextField,Box, Button,
    Backdrop, CircularProgress,
} from '@mui/material';
import toast, { Toaster } from 'react-hot-toast';
import * as Yup from 'yup';

export function PersonalInfo(props) {

    let { handleBack, setClient, client } = props

    const RegisterSchema = Yup.object().shape({
        nit: Yup.string().min(2, 'Demasiado corto!').max(50, 'Demasiado largo!').required('El nit es requerido'),
        cui: Yup.string().min(2, 'Demasiado corto!').max(50, 'Demasiado Largo!').required('Tu CUI/DPI es requerido'),
        direccion: Yup.string().min(2, 'Demasiado corto!').max(50, 'Demasiado Largo!').required('La direccion es requerida'),
        nacimiento: Yup.date().required('Tu fecha  nacimiento es requerida'),
        telefono: Yup.number('Ingresa únicamente números').required('Tu numero de telefono es requerido')
    });

    let [open, setOpen] = useState(false);

    const formik = useFormik({
        initialValues: {
            nit: client.nit,
            cui: client.cui,
            direccion: client.direccion,
            nacimiento: client.nacimiento,
            telefono: client.telefono
        },
        validationSchema: RegisterSchema,
        onSubmit: (values) => {
            setOpen(true);
            // let url = 'http://204.48.25.93:8081/registro'
            // let url = 'http://psicoadmin.ditca.org:8081/registro'
            console.log(client)
            setClient({
                ...client, ...values
            })

            setTimeout(() => {
                let nombre = client.firstName +  " " + client.lastName
                toast.success(`Bienvenido ${nombre} !!`)
                setOpen(false);
            }, 5000)



        }
    });


    const { errors, touched, handleSubmit, getFieldProps } = formik;

    return(
        <FormikProvider style={{ padding : 15}} value={formik}>
            <Form autoComplete="off" noValidate onSubmit={handleSubmit}>
                <Stack spacing={3}>
                    <Stack direction={{ xs: 'column', sm: 'row' }} spacing={2}>
                        <TextField
                            label="Numero de Nit"
                            fullWidth
                            {...getFieldProps('nit')}
                            error={Boolean(touched.nit && errors.nit)}
                            helperText={touched.nit && errors.nit}
                        />

                        <TextField
                            label="CUI/DPI"
                            fullWidth
                            {...getFieldProps('cui')}
                            error={Boolean(touched.cui && errors.cui)}
                            helperText={touched.cui && errors.cui}
                        />
                    </Stack>

                    <TextField
                        fullWidth
                        type="text"
                        label="Dirección"
                        {...getFieldProps('direccion')}
                        error={Boolean(touched.direccion && errors.direccion)}
                        helperText={touched.direccion && errors.direccion}
                    />
                    
                    <Stack direction={{ xs: 'column', sm: 'row' }} spacing={2}>
                        <TextField
                            type="date"
                            label="Fecha de nacimiento"
                            fullWidth
                            InputLabelProps={{  required: true }}
                            {...getFieldProps('nacimiento')}
                            error={Boolean(touched.nacimiento && errors.nacimiento)}
                            helperText={touched.nacimiento && errors.nacimiento}
                        />

                        <TextField
                            label="Telefono"
                            fullWidth
                            {...getFieldProps('telefono')}
                            error={Boolean(touched.telefono && errors.telefono)}
                            helperText={touched.telefono && errors.telefono}
                        />
                    </Stack>

                    <Box sx={{ mb: 2 }}>
                        <div style={{ paddingTop: 15 }}>
                            <Button
                                type="submit"
                                className="registerBtn"
                                variant="contained"
                                // onClick={handleNext}
                                sx={{ mt: 1, mr: 1 }}
                            >
                                {'Registrarme'}
                            </Button>
                            <Button
                                onClick={handleBack}
                                sx={{ mt: 1, mr: 1 }}
                            >
                                Regresar
                            </Button>
                        </div>
                    </Box>

                </Stack>

            </Form>
            <Toaster
                position="top-center"
                reverseOrder={false}
            />
            <Backdrop
                sx={{ color: '#fd4b4b', zIndex: (theme) => theme.zIndex.drawer + 1 }}
                open={open}
                onClick={() => setOpen(false)}
            >
                <CircularProgress color="inherit" />
            </Backdrop>
        </FormikProvider>
    )
}
